@@ -35,7 +35,9 @@
 #include <fcntl.h>
 #include <stdio.h>
 #include <sys/types.h>
+#ifndef G_OS_WIN32
 #include <sys/wait.h>
+#endif
 #include <stdlib.h>
 #include <string.h>
 #include <signal.h>
@@ -49,6 +51,8 @@
 extern int errno;
 #endif
 
+#ifndef G_OS_WIN32
+
 static void
 set_cloexec (gint fd)
 {
@@ -65,6 +69,8 @@ safe_read (int fd, void *buf, size_t count)
   return n;
 }
 
+#endif
+
 /**
  * gnome_execute_async_with_env_fds:
  * @dir: Directory in which child should be executed, or %NULL for current
@@ -86,6 +92,7 @@ gnome_execute_async_with_env_fds (const char *dir, int argc,
 				  char * const envv[], 
 				  gboolean close_fds)
 {
+#ifndef G_OS_WIN32
   int parent_comm_pipes[2], child_comm_pipes[2];
   int child_errno, itmp, i, open_max;
   gssize res;
@@ -211,7 +218,7 @@ gnome_execute_async_with_env_fds (const char *dir, int argc,
 
   /* do this after the read's in case some OS's handle blocking on pipe writes
      differently */
-  waitpid(immediate_child_pid, &itmp, 0); /* eat zombies */
+   while ((waitpid(immediate_child_pid, &itmp, 0)== -1) && (errno == EINTR)); /* eat zombies */
 
   close(parent_comm_pipes[0]);
 
@@ -219,6 +226,12 @@ gnome_execute_async_with_env_fds (const char *dir, int argc,
     g_message("gnome_execute_async_with_env_fds: returning %d", child_pid);
 
   return child_pid;
+#else
+  /* FIXME: Implement if needed */
+  g_warning ("gnome_execute_async_with_env_fds: Not implemented");
+
+  return -1;
+#endif
 }
 
 /**
@@ -357,6 +370,7 @@ gnome_execute_shell (const char *dir, const char *commandline)
 void
 gnome_prepend_terminal_to_vector (int *argc, char ***argv)
 {
+#ifndef G_OS_WIN32
         char **real_argv;
         int real_argc;
         int i, j;
@@ -465,6 +479,10 @@ gnome_prepend_terminal_to_vector (int *argc, char ***argv)
 	/* we use g_free here as we sucked all the inner strings
 	 * out from it into real_argv */
 	g_free (term_argv);
+#else
+	/* FIXME: Implement when needed */
+	g_warning ("gnome_prepend_terminal_to_vector: Not implemented");
+#endif
 }
 
 /**
