@@ -25,33 +25,36 @@
 #define GNOME_URL_H
 
 #include <glib/gmacros.h>
+#include <glib/gerror.h>
 
 G_BEGIN_DECLS
 
+/**
+ * GnomeURLError:
+ * @GNOME_URL_ERROR_PARSE: The parsing of the handler failed.
+ *
+ * The errors that can be returned due to bad parameters being pass to
+ * gnome_url_show().
+ */
 typedef enum {
-  GNOME_URL_ERROR_PARSE /* if the parsing of the handler failed */
+  GNOME_URL_ERROR_PARSE,
+  GNOME_URL_ERROR_LAUNCH,
+  GNOME_URL_ERROR_URL,
+  GNOME_URL_ERROR_NO_DEFAULT,
+  GNOME_URL_ERROR_NOT_SUPPORTED,
+  GNOME_URL_ERROR_VFS
 } GnomeURLError;
 
 #define GNOME_URL_ERROR (gnome_url_error_quark ())
-GQuark gnome_url_error_quark (void) G_GNUC_CONST;
+GQuark   gnome_url_error_quark (void) G_GNUC_CONST;
 
-/* This function displays the given URL in the appropriate viewer.  The
- * Appropriate viewer is user definable, according to these rules:
- *  1) Extract the protocol from URL.  This is defined as everything before
- *     the first colon
- *  2) Check if the key /desktop/gnome/url-handlers/<protocol>-show exists in the
- *     gnome config database.  If it does, use use this as a command
- *     template.  If it doesn't, check for the key
- *     /desktop/gnome/url-handlers/default-show, and if that doesn't exist fallback
- *     on the compiled in default.
- *  3) substitute the %s in the template with the URL.
- *  4) call gnome_execute_shell, with this expanded command as the second
- *     argument.
- */
 
-/* returns FALSE on error, TRUE if everything went fine */
-/* Errors returned are either the GNOME_URL_ERROR_ ones or G_SPAWN_ERROR_ ones */
-gboolean gnome_url_show(const char *url, GError **error);
+gboolean gnome_url_show           (const char  *url,
+				   GError     **error);
+
+gboolean gnome_url_show_with_env  (const char  *url,
+				   char       **envp,
+				   GError     **error);
 
 G_END_DECLS
 #endif
