@@ -29,16 +29,11 @@
 
 #include <stdlib.h>
 #include <glib.h>
+#include <libgnome/gnome-init.h>
 #include <libgnome/gnome-program.h>
 
 G_BEGIN_DECLS
 
-/* locate a program in $PATH, or return NULL if not found */
-char *gnome_is_program_in_path (const gchar *program);
-
-/* Make a dir and a file into a full path, handling / issues. */
-char *g_concat_dir_and_file (const char *dir, const char *file);
-
 /* Return pointer to the character after the last .,
    or "" if no dot. */
 const char * g_extension_pointer (const char * path);
@@ -46,15 +41,15 @@ const char * g_extension_pointer (const char * path);
 
 /* pass in a string, and it will add the users home dir ie,
  * pass in .gnome/bookmarks.html and it will return
- * /home/imain/.gnome/bookmarks.html
+ * /home/imain/.gnome2/bookmarks.html
  * 
  * Remember to g_free() returned value! */
-#define gnome_util_prepend_user_home(x) (g_concat_dir_and_file(g_get_home_dir(), (x)))
+#define gnome_util_prepend_user_home(x) (g_build_filename (g_get_home_dir(), (x), NULL))
 
-/* very similar to above, but adds $HOME/.gnome/ to beginning
+/* very similar to above, but adds $HOME/.gnome2/ to beginning
  * This is meant to be the most useful version.
  */
-#define gnome_util_home_file(afile) (g_strconcat(g_get_home_dir(), "/.gnome/", (afile), NULL))
+#define gnome_util_home_file(afile) (g_build_filename(g_get_home_dir(), GNOME_DOT_GNOME, (afile), NULL))
 
 /* Find the name of the user's shell.  */
 char *gnome_util_user_shell (void);
@@ -67,25 +62,36 @@ int	gnome_setenv (const char *name, const char *value, gboolean overwrite);
 void	gnome_unsetenv (const char *name);
 void	gnome_clearenv (void);
 
+#ifdef G_OS_WIN32
+#if !GLIB_CHECK_VERSION (2, 7, 0)
+gchar*  gnome_win32_locale_filename_from_utf8 (const gchar *utf8filename);
+#else
+#define gnome_win32_locale_filename_from_utf8(x) g_win32_locale_filename_from_utf8 (x)
+#endif
+#endif
+
 /* Some deprecated functions macroed to their new equivalents */
 #ifndef GNOME_DISABLE_DEPRECATED
 
-#define g_file_exists(filename)		g_file_test (filename, G_FILE_TEST_EXISTS)
-#define g_unix_error_string(error_num)	g_strerror (error_num)
+#define g_file_exists(filename)		g_file_test ((filename), G_FILE_TEST_EXISTS)
+#define g_unix_error_string(error_num)	g_strerror ((error_num))
 #define gnome_util_user_home()		g_get_home_dir ()
-#define g_copy_vector(vec)		g_strdupv (vec)
+#define g_copy_vector(vec)		g_strdupv ((vec))
+#define g_concat_dir_and_file(dir,file)	g_build_filename ((dir), (file), NULL)
 
-#define gnome_libdir_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_LIBDIR,  f, TRUE, NULL))
-#define gnome_datadir_file(f) (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_DATADIR, f, TRUE, NULL))
-#define gnome_sound_file(f)   (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_SOUND,   f, TRUE, NULL))
-#define gnome_pixmap_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,  f, TRUE, NULL))
-#define gnome_config_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_CONFIG,  f, TRUE, NULL))
+#define gnome_is_program_in_path(program)	g_find_program_in_path((program))
 
-#define gnome_unconditional_libdir_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_LIBDIR,  f, FALSE, NULL))
-#define gnome_unconditional_datadir_file(f) (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_DATADIR, f, FALSE, NULL))
-#define gnome_unconditional_sound_file(f)   (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_SOUND,   f, FALSE, NULL))
-#define gnome_unconditional_pixmap_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,  f, FALSE, NULL))
-#define gnome_unconditional_config_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_CONFIG,  f, FALSE, NULL))
+#define gnome_libdir_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_LIBDIR,  (f), TRUE, NULL))
+#define gnome_datadir_file(f) (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_DATADIR, (f), TRUE, NULL))
+#define gnome_sound_file(f)   (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_SOUND,   (f), TRUE, NULL))
+#define gnome_pixmap_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,  (f), TRUE, NULL))
+#define gnome_config_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_CONFIG,  (f), TRUE, NULL))
+
+#define gnome_unconditional_libdir_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_LIBDIR,  (f), FALSE, NULL))
+#define gnome_unconditional_datadir_file(f) (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_DATADIR, (f), FALSE, NULL))
+#define gnome_unconditional_sound_file(f)   (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_SOUND,   (f), FALSE, NULL))
+#define gnome_unconditional_pixmap_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,  (f), FALSE, NULL))
+#define gnome_unconditional_config_file(f)  (gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_CONFIG,  (f), FALSE, NULL))
 
 #endif /* GNOME_DISABLE_DEPRECATED */
 
