@@ -45,7 +45,7 @@ impl_Bonobo_PropertyBag_getKeys (PortableServer_Servant  servant,
 	char            *path;
 	Bonobo_KeyList  *retval;
 	GSList          *slist, *sl;
-	GError          *err;
+	GError          *err = NULL;
 	int              length;
 	int              n;
 
@@ -93,7 +93,7 @@ impl_Bonobo_PropertyBag_getType (PortableServer_Servant  servant,
 	BonoboConfigBag *cb = GET_BAG_FROM_SERVANT (servant);
 	char            *path;
 	GConfValue      *value;
-	GError          *err;
+	GError          *err = NULL;
 
 	if (strchr (key, '/')) {
 		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
@@ -126,6 +126,7 @@ impl_Bonobo_PropertyBag_getType (PortableServer_Servant  servant,
 			CORBA_Object_duplicate ((CORBA_Object) BONOBO_ARG_BOOLEAN, ev);
 	default :
 		/* FIXME */
+		break;
 	}
 
 	return CORBA_OBJECT_NIL;
@@ -166,7 +167,7 @@ impl_Bonobo_PropertyBag_getValue (PortableServer_Servant  servant,
 	BonoboConfigBag *cb = GET_BAG_FROM_SERVANT (servant);
 	char            *path;
 	GConfValue      *value;
-	GError          *err;
+	GError          *err = NULL;
  
 	if (strchr (key, '/')) {
 		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
@@ -197,7 +198,7 @@ impl_Bonobo_PropertyBag_setValue (PortableServer_Servant  servant,
 {
 	BonoboConfigBag *cb = GET_BAG_FROM_SERVANT (servant);
 	char            *path;
-	GError          *err;
+	GError          *err = NULL;
 	
 	if (strchr (key, '/')) {
 		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
@@ -248,7 +249,7 @@ impl_Bonobo_PropertyBag_getValues (PortableServer_Servant servant,
 	char *path;
 	Bonobo_PropertySet *retval;
 	GSList *slist, *sl;
-	GError *err;
+	GError *err = NULL;
 	int length;
 	int n;
 
@@ -318,7 +319,7 @@ impl_Bonobo_PropertyBag_getDefault (PortableServer_Servant  servant,
 	BonoboConfigBag *cb = GET_BAG_FROM_SERVANT (servant);
 	char            *path;
 	GConfValue      *value;
-	GError          *err;
+	GError          *err = NULL;
 
 	if (strchr (key, '/')) {
 		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
@@ -347,7 +348,7 @@ impl_Bonobo_PropertyBag_getDocTitle (PortableServer_Servant  servant,
 	char            *path;
 	CORBA_char      *retval;
 	GConfSchema     *schema;
-	GError          *err;
+	GError          *err = NULL;
 
 	if (strchr (key, '/')) {
 		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
@@ -379,7 +380,7 @@ impl_Bonobo_PropertyBag_getDoc (PortableServer_Servant  servant,
 	char            *path;
 	CORBA_char      *retval;
 	GConfSchema     *schema;
-	GError          *err;
+	GError          *err = NULL;
 
 	if (strchr (key, '/')) {
 		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
@@ -412,7 +413,7 @@ impl_Bonobo_PropertyBag_getFlags (PortableServer_Servant  servant,
 	char                 *path;
 	Bonobo_PropertyFlags  retval = 0;
 	GConfEntry           *entry;
-	GError               *err;
+	GError               *err = NULL;
 
 	if (strchr (key, '/')) {
 		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
@@ -438,7 +439,7 @@ impl_Bonobo_PropertyBag_getFlags (PortableServer_Servant  servant,
 }
 
 
-void
+static void
 notify_cb (BonoboListener    *listener,
 	   const char        *event_name, 
 	   const CORBA_any   *any,
@@ -483,7 +484,7 @@ bonobo_config_bag_new (const gchar *path)
 
 	m = g_strconcat ("Bonobo/ConfigDatabase:change", cb->path, ":", NULL);
 
-	//bonobo_event_source_client_add_listener (db, notify_cb, m, NULL, cb);
+	/* bonobo_event_source_client_add_listener (db, notify_cb, m, NULL, cb); */
 
 	g_free (m);
 
